@@ -1,16 +1,9 @@
-#' Test of Structure of a Covariance Matrix given by Srivastava 2005
-#'
-#' @inherit structureCovariances
-#'
-#'
 #' @export
 #'
 #' @references Srivastava, M. S. (2005). Some Tests Concerning the 
 #' Covariance Matrix in High Dimensional Data. Journal of the Japan 
 #' Statistical Society, 35(2), 251-272. \href{http://doi.org/10.14490/jjss.35.251}{10.14490/jjss.35.251}
-#'
-#' @examples Srivastava2005(as.matrix(iris[1:50, 1:4]))
-#'
+#' @rdname structureStatistics
 Srivastava2005 <- function(x, Sigma = "identity", ...){
   UseMethod("Srivastava2005")
 }
@@ -34,14 +27,14 @@ Srivastava2005.covariance <- function(x, Sigma = "identity", ...){
     S_ <- t(x_) %*% x_
   }
 
-  statistic <- Srivastava2005_(n, p, S_)
+  statistic <- Srivastava2005Stat(S_)
   names(statistic) <- "Standard Normal"
 
   parameter <- c(0, 1)
   names(parameter) <- c("Mean", "Variance")
 
   null.value <- 0
-  names(null.value) <- "difference between the Sample Covariance Matrix and the Null Covariance Matrix Structure"
+  names(null.value) <- "difference between the Sample \nCovariance Matrix and the Null Covariance Matrix Structure\n"
 
   p.value <- 1 - pnorm(abs(statistic))
 
@@ -83,14 +76,14 @@ Srivastava2005.matrix <- function(x, Sigma = "identity", ...){
     S_ <- t(x_) %*% x_
   }
 
-  statistic <- Srivastava2005_(n, p, S_)
+  statistic <- Srivastava2005Stat(S_)
   names(statistic) <- "Standard Normal"
 
   parameter <- c(0, 1)
   names(parameter) <- c("Mean", "Variance")
 
   null.value <- 0
-  names(null.value) <- "difference between the Sample Covariance Matrix and the Null Covariance Matrix Structure"
+  names(null.value) <- "difference between the Sample \nCovariance Matrix and the Null Covariance Matrix Structure\n"
   
   p.value <- 1 - pnorm(abs(statistic))
 
@@ -111,9 +104,3 @@ Srivastava2005.matrix <- function(x, Sigma = "identity", ...){
   class(obj) <- "htest"
   obj
 }
-
-#' @keywords internal
-Srivastava2005_ <- function(n, p, S_){
-  n * ((n ^ 2 / (p * (n - 1) * (n + 2))) *
-         (tr(S_ %*% S_) - tr(S_) ^ 2 / n) - 2 * tr(S_) / p + 1) / 2
-}
